train_tools.models.MEDIARFormer — spacr 0.5.0 documentation

# train_tools.models.MEDIARFormer

## Module Contents

class train_tools.models.MEDIARFormer.MEDIARFormer(encoder_name='mit_b5', encoder_weights='imagenet', decoder_channels=(1024, 512, 256, 128, 64), decoder_pab_channels=256, in_channels=3, classes=3)

  Bases: `segmentation_models_pytorch.MAnet`

  MEDIAR-Former Model

  segmentation_head = None
  cellprob_head
  gradflow_head
  forward(x)

    Forward pass through the network